%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author: Aron Yu
% Updated: 09.23.16
%
% Purpose: Demonstrates the correct experimental setup using provided data.
%          Extract a single train/test split and perform learning + evaluation.
%
% Attribute Index: 1 = open, 2 = pointy, 3 = sporty, 4 = comfort
%
% Sources:
%   SVM Ranker: https://filebox.ece.vt.edu/~parikh/relative.html
%   ITML Code: http://www.cs.utexas.edu/~pjain/itml/
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

format short g;

clear all; close all; clc;

load zappos-gist; load zappos-color;
load zappos-labels;
load train-test-splits;
load zappos-ITML-G1-all;

% Determine Attribute & Split
attrIndex = 1;
splitIndex = 1;

imageFeats = [gistfeats colorfeats];   % combine GIST + Color feats
imagePairs = mturkOrder{attrIndex};    % extract pair w/ labels

% Global Train/Test Pair Indices
trainIndex = trainIndexAll{attrIndex}{splitIndex};
testIndex = testIndexAll{attrIndex}{splitIndex};

% Image Pairs w/ Labels
trainPairs = imagePairs(trainIndex,:);
testPairs = imagePairs(testIndex,:);

% Relative Labels (1: A > B, 2: B < A)
trainLabels = trainPairs(:,4);
testLabels = testPairs(:,4);

% Hyperparameters (needs to be validated)
C = 1;
A = A_all{attrIndex};

% Evaluate Target Image One by One
for target_index = 1:length(testLabels)
    
    % Select Target Pair
    targetPair = testPairs(target_index, :);

    % Select Neighboring Pairs
    [trainPairsLocal, ~] = nn_itml(A, targetPair, trainPairs, imageFeats);
    %[trainPairsLocal, ~] = nn_noitml(targetPair, trainPairs, imageFeats);

    % Train RankSVM Model + Evaluate
    [result, ~, ~] = linear_ranksvm(trainPairsLocal, imageFeats, targetPair, C);
    
    predResults(target_index) = result;
    
end

predAccuracy = mean(predResults)
