%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author: Aron Yu
% Updated: 09.23.16
%
% Purpose: Compute RankSVM and evaluate pairwise performance using the
%          original Relative Attributes code.
%
% Source: https://filebox.ece.vt.edu/~parikh/relative.html
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [result, predRank, W] = linear_ranksvm(trainPairs, trainFeats, targetPair, C)

% Train Linear SVM Ranker
% Note: same cost for ordered and equal pairs
[O, S] = prepInput(trainPairs, trainFeats);
C_O = C * ones(size(O,1), 1);                           % cost for ordered pairs
C_S = C * ones(size(S,1), 1);                           % cost for equal pairs
W = ranksvm_with_sim(trainFeats, O, S, C_O, C_S);
predRank = trainFeats * W;                              % predicted rank scores of all images

% Evaluate on Target Pair (if present)
result = [];
if ~isempty(targetPair)
    [~, result] = test_ranksvm(predRank, targetPair);   % raw result (0: incorrect, 1:correct)
end
