%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author: Aron Yu
% Updated: 03.19.15
%
% Purpose: Determine nearest neighbor pairs based on ITML distance.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [trainPairsITML, sortIdx] = nn_itml(M, targetPair, compPairs, distFeats)

% Compute Pairwise Similarity
d11 = bsxfun(@minus, distFeats(compPairs(:,1),:), distFeats(targetPair(1),:));
d22 = bsxfun(@minus, distFeats(compPairs(:,2),:), distFeats(targetPair(2),:));
option1 = sum(d11 * M .*d11, 2) .* sum(d22 * M .*d22, 2);

d12 = bsxfun(@minus, distFeats(compPairs(:,1),:), distFeats(targetPair(2),:));
d21 = bsxfun(@minus, distFeats(compPairs(:,2),:), distFeats(targetPair(1),:));
option2 = sum(d12 * M .*d12, 2) .* sum(d21 * M .*d21, 2);

pairDistMin = min(option1, option2);

% Sort Nearest Neighbors
[~, sortIdx] = sort(pairDistMin, 'ascend');
trainPairsITML = compPairs(sortIdx, :);
