%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author: Aron Yu
% Updated: 09.23.16
%
% Purpose: Evaluate pairwise ranking performance.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [perc_correct, test_result] = test_ranksvm(predRanks, targetPair)

num_data = size(targetPair,1);

% Organize Supervision Data (Ground Truth)
test_ims = zeros(2*num_data,1);
test_ranks = zeros(2*num_data,1);

for i = 1:num_data
    
    % Decode Image Index
    off = 2*(i-1)+1;
    test_ims(off:off+1) = [targetPair(i,1); targetPair(i,2)];
    
    % Decode Relative Result
    resp = targetPair(i,4);
    if (resp == 1)
        test_ranks(off:off+1) = [2;1];
    elseif (resp == 2)
        test_ranks(off:off+1) = [1;2];
    else
        assert(resp == 3);
        test_ranks(off:off+1) = [1;1];
    end
    
end

% Look at the Relevant Images Only
predRanks = predRanks(test_ims);
assert(mod(length(predRanks), 2)==0, 'Decoded ground truth is not even!');

% Compare Predicted Ranks to Actual Ranks
num_correct = 0;
test_result = zeros(num_data,1);
for j = 1:2:length(predRanks)
    if (  ((predRanks(j) > predRanks(j+1)) && (test_ranks(j) > test_ranks(j+1))) || ...
          ((predRanks(j) < predRanks(j+1)) && (test_ranks(j) < test_ranks(j+1)))  )
        num_correct = num_correct + 1;
        test_result((j+1)/2) = 1;
    end
end

perc_correct = 2 * num_correct / length(predRanks);
